class parser:
    def __init__(self, path, sep=','):
        self.sep=sep
        self.path = path

    def excel_to_csv(self):
        try:
            import sys
            import pandas as pd
        except ImportError:
            print("pandas is not installed. Please install it and try again.")
            sys.exit(1)
        df = pd.read_excel(self.path)
        if self.path.endswith('.xlsx'):
            self.path = self.path[:-5]
        if self.path.endswith('.xls'):
            self.path = self.path[:-4]        
        df.to_csv(self.path + '.csv', index=False, sep=self.sep)


from distutils.core import setup
from pathlib import Path

this_directory = Path(__file__).parent
readme = (this_directory / "README.md").read_text()

setup(
    name = 'felisaparser',
    version = '1.0.4',
    description = 'This package contains a function to directly parse a excel file into a csv file',
    author = 'Adrián Martínez, David Del Río',
    url = 'https://github.com/daviddelriod/felisaparser',
    keywords = ['xlsx parser'],
    long_description=readme,
    long_description_content_type='text/markdown',
    install_requires = [
        'pandas',
        ],
)